require 'fundler_spec_helper'

class TestFundler
  describe Fundler do
    context 'file utils' do
      let(:finder) { Fundler.new }
      before(:each) do
        FileUtils::mkdir 'test'
        File.open('test/example', 'w') do |f|
          f.puts '#!/usr/bin/env ruby'
          f.puts '# encoding: utf-8'
          f.puts 'x = 0'
          f.puts 'puts x'
        end
        File.open('test/example_rb.rb', 'w') do |f|
          f.puts 'x = :foo'
          f.puts 'puts x'
        end
        File.open('test/list.txt', 'w') do |f|
          f.puts 'grocery list'
          f.puts '- chunky bacon'
        end
        File.open('test/SpAcE  cAmEl.txt', 'w') do |f|
          f.puts 'foo!'
        end
      end
      after(:each) do
        FileUtils::rm_rf 'test'
      end
      
      it 'finds all files' do
        FileUtils::cd './test' do
          expect(finder.all_files()).to eq(['example', 'example_rb.rb', 'list.txt', 'SpAcE  cAmEl.txt'].sort)
        end
      end
      it 'finds a file with no .rb extension but has a shebang line' do
        FileUtils::cd './test' do
          expect(finder.ruby_files()).to eq(['example', 'example_rb.rb'])
        end
      end
      it 'clean all filenames' do
        FileUtils::cd './test' do
          expect(finder.clean_all_filenames()).to eq(4)
          expect(finder.all_files()).to eq(['example', 'example_rb.rb', 'list.txt', 'space_camel.txt'].sort)
        end
      end
      it 'show the pwd (last dir in this spec)' do
        FileUtils::cd './test' do
          expect(finder.get_pwd.split('/').last).to eq('test')
        end
      end

    end # context
  end # describe
  
end #TestFundler
